@@ -2,6 +2,7 @@
 Concept and most code taken from one
 of the snippets at djangosnippets.com
 '''
+import sys
 import logging
 
 DEFAULT_LEVEL = logging.INFO
@@ -29,3 +30,5 @@ LOG_SQL = getattr(django_settings, 'DJALOG_SQL', False)
 LOG_SQL_LEVEL = getattr(django_settings, 'DJALOG_SQL_LEVEL', 5)
 LOG_LEVEL = getattr(django_settings, 'DJALOG_LEVEL', DEFAULT_LEVEL)
 LOG_USE_COLORS = getattr(django_settings, 'DJALOG_USE_COLORS', False)
+LOG_STREAM = getattr(django_settings, 'DJALOG_STREAM', sys.stdout)
+
